@@ -119,15 +119,15 @@ def end():
 	print(now('micro')-start_time)
 class mysql(object):
 	conn=None
-	def __init__(self, host='127.0.0.1',**args):
+	def __init__(self, host=None,**args):
 		import pymysql
 		self.pymysql=pymysql
-		connect_config={'host':host,'user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor,'autocommit':None}
+		connect_config={'host':'127.0.0.1','user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor,'autocommit':None}
 		if 'table' in args:
 			self.table=args['table']
 			del args['table']
 		if not args:
-			args=obj(name='mysql')
+			args=obj(name='mysql' if host is None else f'mysql_{host}')
 		for x in args:
 			connect_config[x]=args[x]
 		self.connect_config = connect_config
@@ -238,6 +238,12 @@ class redis(object):
 		self.redis=redis.StrictRedis(host=host, port=port, db=db,decode_responses=True)
 	def __getattr__(self,attr):
 		return getattr(self.redis,attr)
+def process_arg_construct(urls:list,args):#args must be iterable
+	proc_args=[]
+	every_proc_count=math.ceil(len(args)/len(urls))
+	for i,url in enumerate(urls):
+		proc_args.append((url,args[i*every_proc_count:i*every_proc_count+every_proc_count]))
+	return proc_args
 def process(target,is_thread=True,join=False,num=1,sleep=None,**args):
 	if isinstance(target,str):#args:target,[sync=False]
 		import subprocess
